function ModelParameters = UpdateSWWParameters(ModelParameters)
% UpdateGSWParameters: Shows how to define new parameters from previously defined parameters
%                      for the Smets-Warne-Wouters (2014) model.
%
% USAGE:
%
%       ModelParameters = UpdateSWWParameters(ModelParameters)
%
% REQUIRED INPUT:  ModelParameters (structure) with fields corresponding to the parameters
%                                   you need for defining new parameters that should be
%                                   added to the structure.
%
% REQUIRED OUTPUT: ModelParameters (structure) with additions to the input structure.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   DG-R/EMO
%                                   European Central Bank
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2017 European Central Bank.
%
%                       First version: August 19, 2011.
%                        This version: February 10, 2017.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 28-02-2014: Updated the documentation.
%
% * 13-01-2015: Updated the documentation.
%
% * 21-01-2016: Updated the documentation.
%
% * 10-02-2017: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

%
% Parameter functions related to the steady-state of the Smets and Wouters model
%
ModelParameters.gamma = (ModelParameters.gammabar/100)+1;
ModelParameters.pistar = (ModelParameters.pibar/100)+1;
ModelParameters.beta = 1/((ModelParameters.betainv/100)+1);
ModelParameters.betabar = ModelParameters.beta*(ModelParameters.gamma^(-ModelParameters.sigmac));
ModelParameters.rbar = 100*((ModelParameters.pistar/ModelParameters.betabar)-1);
ModelParameters.ubar = (ModelParameters.phiw-1)/ModelParameters.sigmal;
%
% steady-state rental rate of capital
%
ModelParameters.rkstar = (1/ModelParameters.betabar)+ModelParameters.delta-1;
%
% steady-state real wages
%
ModelParameters.w = (ModelParameters.alpha^ModelParameters.alpha*(1-ModelParameters.alpha)^(1-ModelParameters.alpha)/(ModelParameters.phip*ModelParameters.rkstar^ModelParameters.alpha))^(1/(1-ModelParameters.alpha));
%
% steady-state investment-capital ratio
%
ModelParameters.ik = ModelParameters.gamma+ModelParameters.delta-1;
%
% steady-state labor-capital ratio
%
ModelParameters.lk = ((1-ModelParameters.alpha)/ModelParameters.alpha)*(ModelParameters.rkstar/ModelParameters.w);
%
% steady-state capital-output ratio
%
ModelParameters.ky = ModelParameters.phip*(ModelParameters.lk^(ModelParameters.alpha-1));
%
% steady-state investment-output ratio
%
ModelParameters.iy = ModelParameters.ik*ModelParameters.ky;
%
% steady-state consumption-output ratio
%
ModelParameters.cy = 1-ModelParameters.gy-ModelParameters.iy;
%
% steady-state rental rate of capital times capital output ratio
%
% zy = rkstar*ky = alpha
%
ModelParameters.zy = ModelParameters.alpha;
%
% steady-state real-wage bill to consumption ratio 
%
ModelParameters.whlcstar = (1-ModelParameters.alpha)/(ModelParameters.phiw*ModelParameters.cy);

%
% end of UpdateGSWParameters.m
%
