function FileName = TrimPath(FileName,Directory)
% TrimPath: Checks if the beginning of the path for the filename can be removed.
%
% USAGE:
%
%       FileName = TrimPath(FileName,Directory)
%
% REQUIRED INPUT:  FileName (string) with the full path and name of a file.
%
%                  Directory (string) with the beginning part of the path that may be trimmed.
%
% REQUIRED OUTPUT: FileName (string) with the outcome of the possible trimming.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   DG-R/MPR
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2017 European Central Bank.
%
%                       First version: January 13, 2011.
%                        This version: March 20, 2017.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 14-01-2011: Updated the documentation.
%
% * 01-09-2011: If "FileName" and "Directory" are equal the function now returns an empty string.
%
% * 03-01-2012: Updated the documentation.
%
% * 03-01-2013: Updated the documentation.
%
% * 27-01-2014: Updated the documentation.
%
% * 13-01-2015: Updated the documentation.
%
% * 21-01-2016: Updated the documentation.
%
% * 20-03-2017: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

DirLength = length(Directory);
FileLength = length(FileName);
if FileLength<=DirLength;
   if strcmp(lower(FileName),lower(Directory))==1;
      FileName = '';
   end;
   return;
end;
if ispc==1;
   if (strcmp(lower(FileName(1:DirLength)),lower(Directory))==1)&(strcmp(FileName(DirLength+1),'\')==1);
      FileName = FileName(DirLength+1:FileLength);
   end;
else;
   if (strcmp(FileName(1:DirLength),Directory)==1)&(strcmp(FileName(DirLength+1),'/')==1);
      FileName = FileName(DirLength+1:FileLength);
   end;
end;

%
% end of TrimPath.m
%
