function ShowStatus
% ShowStatus: Displays text from axes or uicontrol object on the status bar.
%
% USAGE:
%
%       ShowStatus
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   DG-R/MPR
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2017 European Central Bank.
%
%                       First version: July 25, 2006.
%                        This version: February 10, 2017.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 03-01-2008: Made sure that uicontrol and axes has a valid handle and that it is visible.
%
% * 19-05-2008: Cleaned up the function.
%
% * 20-06-2008: Updated the documentation.
%
% * 23-05-2008: Updated the documentation.
%
% * 19-12-2008: Updated the documentation.
%
% * 02-05-2009: Updated the documentation.
%
% * 06-01-2010: Updated the documentation.
%
% * 26-01-2010: The function now calls "overobj" instead of "OverObject" when the user
%               has matlab verion 6 or later.
%
% * 04-01-2011: Updated the documentation.
%
% * 04-01-2012: Updated the documentation.
%
% * 06-02-2012: Added a test if "controls.status" is a valid handle when "co" is empty, not a handle,
%               or not visible.
%
% * 06-06-2012: Added tests if "status" and "quitmenu" are fields in "controls".
%
% * 02-01-2013: Updated the documentation.
%
% * 24-01-2014: Updated the documentation.
%
% * 05-01-2015: Updated the documentation.
%
% * 18-03-2015: Switched to the new IsHandle function.
%
% * 20-01-2016: Updated the documentation.
%
% * 10-02-2017: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

fig = findobj('Type','figure','Tag','YADA');
%
if isempty(fig)==0;
   controls = get(fig,'UserData');
   ud = get(controls.status,'UserData');
   %
   if MatlabNumber>=6;
      co = overobj('uicontrol');
   else;
      co = OverObject('uicontrol');
   end;
   if (isempty(co)==0)&(IsHandle(co)==1)&(strcmp(lower(get(co,'Visible')),'off')==0);
      if strcmp(lower(get(co,'Style')),'popupmenu')==1;
         pop_str = get(co,'String');
         pop_val = get(co,'Value');
         pop_str = pop_str(pop_val,:);
         if isfield(controls,'status')==1;
            set(controls.status,'String',pop_str);
         end;
         if isfield(controls,'quitmenu')==1;
            set(controls.quitmenu,'UserData',pop_str);
         end;
         return;
      end;
      co_str = get(co,'TooltipString');
      if isempty(co_str)==1;
         co_str = get(co,'String');
         if isempty(co_str)==0;
            co_str = co_str(1,:);
         end;
      end;
      if (isempty(co_str)==0)&(isequal(controls.status,co)==0);
         if isfield(controls,'status')==1;
            set(controls.status,'String',co_str);
         end;
         if isfield(controls,'quitmenu')==1;
            set(controls.quitmenu,'UserData',co_str);
         end;
      else;
         if isfield(controls,'status')==1;
            set(controls.status,'String',ud.string);
         end;
         if isfield(controls,'quitmenu')==1;
            set(controls.quitmenu,'UserData',ud.string);
         end;
      end;
   else;
      if IsHandle(controls.status)==1;
         if isfield(controls,'status')==1;
            set(controls.status,'String',ud.string);
         end;
         if isfield(controls,'quitmenu')==1;
            set(controls.quitmenu,'UserData',ud.string);
         end;
      end;
   end;
   drawnow;
end;

%
% end of ShowStatus.m
%
