function logGPR = LogGammaProductRatio(n,a,b)
% LogGammaProductRatio: Computes the log of the ratio of two Gamma product functions with
%                       the same dimension.
%
% USAGE:
%
%       logGPR = LogGammaProductRatio(n,a,b)
%
% REQUIRED INPUT:  n (positive integer) the common dimension of the product.
%
%                  a (positive integer) to supply to the gamma product function
%                    in the numerator.
%
%                  b (positive integer) to supply to the gamma product function
%                    in the denominator.
%
% NOTE: The Gamma product is defined as:
%
%             GP = Prod(i=1:n) Gamma([a-i+1]/2)
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   DG-R/MPR
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2017 European Central Bank.
%
%                       First version: January 20, 2010.
%                        This version: March 21, 2017.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 21-01-2010: Updated the documentation.
%
% * 05-01-2011: Updated the documentation.
%
% * 04-01-2012: Updated the documentation.
%
% * 03-01-2013: Updated the documentation.
%
% * 28-01-2014: Updated the documentation.
%
% * 14-01-2015: Updated the documentation.
%
% * 27-01-2016: Remember Shoah.
%
% * 21-03-2017: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

logGPR = 0;
for i=1:n;
   logGPR = logGPR + gammaln((a-i+1)/2) - gammaln((b-i+1)/2);
end;

%
% end of gamma_product.m
%
