function YADAf = YADAInline(FcnStr)
% YADAInline: Creates an inline function with all argument ordered correctly
%
% USAGE:
%
%       YADAf = YADAInline(FcnStr)
%
% REQUIRED INPUT:  FcnStr (string vector) that is sent to the inline function.
%
% REQUIRED OUTPUT: YADAf (function) that is a proper inline function with the input arguments
%                        ordered exactly as they appear on the FcnStr
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   DG-R/MPR
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2017 European Central Bank.
%
%                       First version: November 20, 2007.
%                        This version: March 21, 2017.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 23-05-2008: Updated the documentation.
%
% * 18-09-2008: Fixed a bug for the NamesOrder variable. New method instead of using findstr in FcnStr string.
%               The former leads to false positives, while new method is precise.
%
% * 21-02-2009: Updated the documentation.
%
% * 03-05-2009: Updated the documentation.
%
% * 05-01-2010: Updated the documentation.
%
% * 05-01-2011: Updated the documentation.
%
% * 04-01-2012: Updated the documentation.
%
% * 03-01-2013: Updated the documentation.
%
% * 28-01-2014: Updated the documentation.
%
% * 14-01-2015: Updated the documentation.
%
% * 27-01-2016: Remember Shoah.
%
% * 21-03-2017: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

%
% get the argument names
%
Names = argnames(inline(FcnStr));
if isempty(Names)==1;
   YADAf = inline(FcnStr);
   return;
end;
NamesOrder = zeros(length(Names),1);
%
% remove mathematical characters from function string
%
fcnStr = strrep(FcnStr,'+',' ');
fcnStr = strrep(fcnStr,'-',' ');
fcnStr = strrep(fcnStr,'/',' ');
fcnStr = strrep(fcnStr,'*',' ');
fcnStr = strrep(fcnStr,'[',' ');
fcnStr = strrep(fcnStr,'(',' ');
fcnStr = strrep(fcnStr,')',' ');
fcnStr = strrep(fcnStr,']',' ');
fcnStr = strrep(fcnStr,'''',' ');
fcnStr = strrep(fcnStr,';',' ');
fcnStr = strrep(fcnStr,'.',' ');
fcnStr = strrep(fcnStr,',',' ');
fcnStr = strrep(fcnStr,':',' ');
fcnStr = strrep(fcnStr,'{',' ');
fcnStr = strrep(fcnStr,'}',' ');
FcnMat = Str2Matrix([fcnStr ' '],' ');
for i=1:length(Names);
   for j=1:size(FcnMat,1);
      if strcmp(Names{i},StringTrim(FcnMat(j,:)))==1;
         NamesOrder(i) = j;
         break;
      end;
   end;
end;
[Pos,Ind] = sort(NamesOrder);
Names = Names(Ind);
%
% we now have a proper order for the names
%
ArgStr = 'FcnStr';
for i=1:length(Names);
   ArgStr = strcat(ArgStr,[',''' Names{i} '''']);
end;
eval(['YADAf = inline(' ArgStr ');']);

%
% end of YADAInline.m
%
