function controls = HelpMenuControls(maingui,controls)
% HelpMenuControls: sets up the Help menu.
%
% USAGE:
%
%       controls = HelpMenuControls(maingui,controls)
%
% REQUIRED INPUT:  maingui (handle) to YADA's main dialog.
%
%                  controls (structure) with handles to the controls on the YADA main dialog.
%
% REQUIRED OUTPUT: controls (structure) with handles to the controls on the YADA main dialog.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   Forecasting and Policy Modelling Division
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2017 European Central Bank.
%
%                       First version: March 3, 2010.
%                        This version: September 15, 2017.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 04-03-2010: Updated the documentation.
%
% * 05-01-2011: Updated the documentation.
%
% * 29-01-2011: Added the YADA homepage control.
%
% * 02-01-2012: Updated the documentation.
%
% * 03-01-2013: Updated the documentation.
%
% * 28-01-2014: Updated the documentation.
%
% * 14-01-2015: Updated the documentation.
%
% * 27-01-2016: Remember Shoah.
%
% * 17-03-2017: Added a control for viewing the html version of the help file in windoze.
%
% * 15-09-2017: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

%
% Help menu
%
controls.helpmenu = uimenu('Parent',maingui, ...
   'Label','&Help', ...
   'Tag','HelpMenu');
%
% Objects on Help menu
%
controls.helpfilemenu = uimenu('Parent',controls.helpmenu, ...
   'Label','&Help', ...
   'Callback','HelpMenuFunctions HelpFile', ...
   'Enable','on', ...
   'Tag','HelpFileMenu');
%
if ispc==1;
   controls.htmlhelpfilemenu = uimenu('Parent',controls.helpmenu, ...
      'Label','&Browser-Based Help', ...
      'Callback','HelpMenuFunctions HTMLHelpFile', ...
      'Enable','on',...
      'Tag','HTMLHelpFileMenu');
end;
%
controls.yadamanual = uimenu('Parent',controls.helpmenu, ...
   'Label','&Manual - Computational Details (PDF)', ...
   'Callback','HelpMenuFunctions YADAManual', ...
   'Enable','on', ...
   'Tag','ManualMenu');
%
controls.extendyada = uimenu('Parent',controls.helpmenu, ...
   'Label','&Extending YADA (PDF)', ...
   'Callback','HelpMenuFunctions ExtendYADA', ...
   'Enable','on', ...
   'Tag','ExtendYADAMenu');
%
controls.yadahomepage = uimenu('Parent',controls.helpmenu, ...
   'Label','&YADA Cyberspace Connection', ...
   'Callback','HelpMenuFunctions YADAHomepage', ...
   'Separator','on', ...
   'Enable','on', ...
   'Tag','YADAHomepageMenu');
%
controls.license = uimenu('Parent',controls.helpmenu, ...
   'Label','&License', ...
   'Callback','HelpMenuFunctions License', ...
   'Separator','on', ...
   'Enable','on', ...
   'Tag','LicenseMenu');
%
controls.aboutmenu = uimenu('Parent',controls.helpmenu, ...
   'Label','&About', ...
   'Callback','HelpMenuFunctions About', ...
   'Separator','on', ...
   'Enable','on', ...
   'Tag','AboutMenu');

%
% end of HelpMenuControls.m
%
