function Bounds = HighestProbabilityDensityBand(VarData,ConfDraws)
% HighestProbabilityDensityBand: Computes (1-alpha)*100 percent highest probability density bands under
%                                the assumption that the distribution is unimodal.
%
% USAGE:
%
%       Bounds = HighestProbabilityDensityBand(VarData,ConfDraws)
%
% REQUIRED INPUT:  VarData (vector) of dimension NumDraws with sorted draws from the underlying distribution.
%
%                  ConfDraws (integer) equal to (1-alpha)*NumDraws determining the number of draws within
%                            the desired credible interval.
%
% REQUIRED OUTPUT: Bounds (vector) of dimension 1x2 with the value of the lower and the upper bound.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   DG-R/MPR
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2017 European Central Bank.
%
%                       First version: August 24, 2012.
%                        This version: March 22, 2017.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 27-08-2012: Updated the documentation.
%
% * 29-08-2012: Made sure that "ConfDraws" is always positive.
%
% * 03-01-2013: Updated the documentation.
%
% * 28-01-2014: Updated the documentation.
%
% * 14-01-2015: Updated the documentation.
%
% * 22-02-2016: Updated the documentation.
%
% * 22-03-2017: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

%
% initialize
%
NumDraws = length(VarData);
ConfDraws = max(ConfDraws,1);
Bounds = [VarData(1) VarData(ConfDraws)];
for i=1:NumDraws-ConfDraws+1;
   if (VarData(ConfDraws+i-1)-VarData(i))<(Bounds(2)-Bounds(1));
      Bounds = [VarData(i) VarData(ConfDraws+i-1)];
   end;
end;

%
% end of HighestProbabilityDensityBand.m
%
