function PrintPosteriorModeResults(DSGEModel,CurrINI,ParameterNames,phiMode,thetaMode,phi,theta,thetaCalibrated,thetaAdditionalInitial,thetaAdditionalMode,thetaDist,PriorDist,ThetaPhiPartial,InverseHessian,phiInverseHessianFinDiff,phiFittedStd,thetaFittedStd,phiPostModeStdFinDiff,thetaPostModeStdFinDiff,LogPostDensity,LogLikeDensity,LogPriorDensity,LogJacobianValue,ExtremeCorrParameters,SmallEigenValues,SmallEigenVectors,OptAlgorithm,OptParameters,MaxTime,ToleranceValue,MaxIter,NumIter,FuncDiff,MaxEigenvalueIV,MaxEigenvalueMode,OptResults,ScreenMessages,LogPosteriorPhiIV,LogPosteriorThetaIV,LogPriorDensityIV,NumMeasureErrors,MFEYMode,MSEYMode,MFEYIV,MSEYIV,LogSPIV,LogSPMode,IsSystemPrior,LogMargLikeSystemLaplace)
% PrintPosteriorModeResults: Writes a summary of the output from sucessful posterior mode estimation run to text file
%                            in the output directory.
%
% USAGE:
%
%       PrintPosteriorModeResults(DSGEModel,CurrINI,ParameterNames,phiMode,thetaMode,phi,theta,thetaCalibrated, ...
%                 thetaAdditionalInitial,thetaAdditionalMode,thetaDist,PriorDist,ThetaPhiPartial,InverseHessian, ...
%                 phiInverseHessianFinDiff,phiFittedStd,thetaFittedStd,phiPostModeStdFinDiff,thetaPostModeStdFinDiff, ...
%                 LogPostDensity,LogLikeDensity,LogPriorDensity,LogJacobianValue,ExtremeCorrParameters,SmallEigenValues, ...
%                 SmallEigenVectors,OptAlgorithm,OptParameters,MaxTime,ToleranceValue,MaxIter,NumIter,FuncDiff,MaxEigenvalueIV, ...
%                 MaxEigenvalueMode,OptResults,ScreenMessages,LogPosteriorPhiIV,LogPosteriorThetaIV,LogPriorDensityIV, ...
%                 NumMeasureErrors,MFEYMode,MSEYMode,MFEYIV,MSEYIV,LogSPIV,LogSPMode,IsSystemPrior,LogMargLikeSystemLaplace)
%
% REQUIRED INPUT: DSGEModel (structure) whose fields contain all required information
%                           about the model, such as input files, variable and sample
%                           data. Actual observations are not stored in this file.
%
%                 CurrINI (structure), with initialization information.
%
%                 ParameterNames (structure) with fields "calibrated", "beta", "gamma", "normal", "invgamma", "truncnormal",
%                           "uniform", "student", "cauchy", "logistic", "gumbel", "pareto", "all" and "estimated". Each
%                           field returns a string matrix with the parameter names.
%
%                 phiMode (vector) with the transformed parameters to estimate at the posterior mode
%
%                 thetaMode (vector) with the original parameters to estimate at the posterior mode
%
%                 phi (vector) with the initial values of the transformed parameters
%
%                 theta (vector) with the initial values of the original parameters.
%
%                 thetaCalibrated (vector) with values of any calibrated DSGE model parameters .
%
%                 thetaAdditionalInitial (vector) with initial values of any additional DSGE model parameters.
%
%                 thetaAdditionalMode (vector) with the posterior mode values of any additional DSGE model parameters.
%
%                 thetaDist (vector) with integers 1 if gamma, 2 if beta, 3 if normal, 4 if invgamma, 5 if
%                           truncnormal, 6 if uniform, 7 if student, 8 if cauchy, 9 if logistic, 10 if gumbel,
%                           and 11 if pareto.
%
%                 PriorDist (structure) with fields "beta", "gamma", "normal", "invgamma", "truncnormal", "uniform",
%                           "student", "cauchy", "logistic", "gumbel", and "pareto", where the values are matrices with the
%                           parameter values for the distributions. In the case of the normal, beta, gamma, logistic 
%                           and gumbel these parameter values are the mean and the standard deviation. For the invgamma
%                           it is the s and q parameters, where q is a positive integer (degrees of freedom). For the left
%                           truncated normal there's a third parameter, the lower bound. For the uniform the parameter
%                           values are the lower and the upper bound. For the student-t they are the location (mode),
%                           the scale and the degrees of freedom parameter, while for the Cauchy only the location
%                           and scale parameters are needed. For the Pareto the parameter values are for the mode
%                           and the shape parameter.
%
%                 ThetaPhiPartial (matrix) where the diagonal entries give the partial derivatives of the original
%                           parameters wrt the transformed parameters. Evalues at the mode.
%
%                 InverseHessian (matrix), the inverse of the Hessian at the mode of the transformed parameters.
%                           This matrix is provides directly from the optimization routine.
%
%                 phiInverseHessianFinDiff (matrix) with minus the inverse Hessian at the mode of the transformed
%                           parameters using finite differences. This matrix is used for the Laplace approximation.
%
%                 phiFittedStd (vector) of standard deviations of the transformed parameters. This vector is given
%                           as output by "VillaniCheckOptimum".
%
%                 thetaFittedStd (vector) of standard deviations of the original parameters.
%
%                 phiPostModeStdFinDiff (vector) of standard deviations from applying the finite difference based
%                           inverse Hessian for the transformed parameters.
%
%                 thetaPostModeStdFinDiff (vector) of standard deviations from applying the finite difference based
%                           inverse Hessian for the original parameters.
%
%                 LogPostDensity (scalar), the value of the log posterior of the transformed parameters at the mode.
%
%                 LogLikeDensity (scalar), the value of the log likelihood function of the original parameters at the mode.
%
%                 LogPriorDensity (scalar), the value of the log prior density of the original parameters at the mode.
%
%                 LogJacobianValue (scalar), the value of the log Jacobian in the transformation from the original
%                            parameters to the transformed parameters.
%
%                 ExtremeCorrParameters (cell array), with parameter pairs having absolute correlations equal to or
%                            greater than 0.7. The dimension of the cell array is equal to the number of such extreme
%                            correlations times 3. The columns contains the name of parameter 1 (string), the name of
%                            parameter 2 (string), and the estimated correlation (scalar).
%
%                 SmallEigenValues (vector) of dimension s with the smallest eigenvalues of the
%                            information matrix.
%
%                 SmallEigenVectors (matrix) of dimension pxs with the eigenvectors that are
%                            associated with the small eigenvalues.
%
%                 OptAlgorithm (string vector), with either "fminunc" or "csminwel" being the optimization algorithm
%                            used to calculate the posterior mode.
%
%                 OptParameters (string vector) that takes the value "Transformed" or "Original" and refers to
%                            which parameters were used as target during optimization.
%
%                 MaxTime (scalar), the time in seconds to complete the optimization problem.
%
%                 ToleranceValue (scalar), the tolerance value used when evaluating if the optimization algorithm has
%                            converged or not.
%
%                 MaxIter (positive integer), the maximum number of iterations considered by the optimization algorithm.
%
%                 NumIter (positive integer), the actual number of iteration used by the optimization algorithm.
%
%                 FuncDiff (scalar), the value of the convergence measure.
%
%                 MaxEigenvalueIV (scalar), the largest absolute eigenvalue of the state equation transition matrix at
%                            the initial value of theta.
%
%                 MaxEigenvalueMode (scalar), the largest absolute eigenvalue of the state equation transition matrix at
%                            the posterior mode of theta.
%
%                 OptResults (matrix), of dimension (NumIter x 4) containing iteration no, value of log posterior, value
%                            of convergence measure, and the largest absolute value of the gradient.
%
%                 ScreenMessages (string matrix) with all the screen messages that csminwel could have produced.
%
%                 LogPosteriorPhiIV (scalar), value of the log posterior of phi at the initial value of phi.
%
%                 LogPosteriorThetaIV (scalar), value of the log posterior of theta at the initial value of theta.
%
%                 LogPriorDensityIV (sclara), value of the log prior desnity of theta at the initial value of theta.
%
%                 NumMeasureErrors (integer), giving the number of measurement errors in the model.
%
%                 MFEYMode (vector), with the mean forecast errors of the 1-step ahead forecasts of the observed
%                            variables when the parameters are evaluated at the mode.
%
%                 MSEYMode (matrix) with the mean squared errors of the 1-step ahead forecasts of the observed
%                            variables when the parameters are evaluated at the mode.
%
%                 MFEYIV (vector), with the mean forecast errors of the 1-step ahead forecasts of the observed
%                            variables when the parameters are evaluated at the initial values.
%
%                 MSEYIV (matrix) with the mean squared errors of the 1-step ahead forecasts of the observed
%                            variables when the parameters are evaluated at the initial values.
%
%                 LogSPIV (scalar) with the value of the system prior at the initial values.
%
%                 LogSPMode (scalar) with the value of the system prior at the mode.
%
%                 IsSystemPrior (boolean) that takes the value 1 if a system prior is used and 0 otherwise.
%
%                 LogMargLikeSystemLaplace (scalar) with the value of the log marginal likelihood of the
%                            system prior.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   DG-R/MPR
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2017 European Central Bank.
%
%                       First version: August 11, 2006.
%                        This version: June 1, 2017.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 14-08-2006: Included the inputs "thetaCalibrated", "thetaAdditionalInitial", "thetaAdditionalMode". The text written to file
%               was also changed regarding parameter estimates.
%
% * 22-08-2006: Included the inputs "MaxEigenvalueIV" and "MaxEigenvalueMode"
%
% * 23-08-2006: Added the input "OptResults", "LogPosteriorPhiIV", "LogPosteriorThetaIV", "LogPriorDensityIV", 
%               "NumMeasureErrors", "MFEYMode", "MSEYMode", "MFEYIV" and "MSEYIV".
%
% * 24-08-2006: Added the calls to the StrWrap function to make sure that the variable names string are wrapped if they
%               are too long.
%
% * 22-09-2006: Added some checks for empty string rows of string matrices when writing variable names to the output file. If
%               the prior distribution involves left truncated normal parameters, then the lower bound is now also written
%               to the output file.
%
% * 16-10-2006: Fixed an output issue when the prior distribution is left truncated normal. The output had one space characted
%               too many before.
%
% * 17-10-2006: Minor fixes for the output of initialized (calibrated) and updated parameters.
%
% * 20-10-2006: Added the call to the "MargLikeLaplace" function for getting an approximation of the log marginal
%               likelihood based on the Laplace approximation.
%
% * 09-11-2006: Added information about the actual sample used.
%
% * 20-11-2006: Changed the prt_val string when the log posterior values are written to file from 12.6f to 15.6f.
%
% * 22-11-2006: Fixed a spelling error.
%
% * 08-12-2006: Added "(hrs:min:sec)" to the time output string.
%
% * 17-04-2007: Updated the documentation.
%
% * 13-11-2007: Updated the documentation.
%
% * 02-01-2008: Removed code using "DSGEModel.InitializeKalman".
%
% * 23-05-2008: Updated the documentation.
%
% * 22-07-2008: Took into account that the gamma and inverted gamma distributions now use the lower bound parameter.
%
% * 23-07-2008: Took into account that the beta distribution supports general lower and upper bounds.
%
% * 23-10-2008: Added information about the number of parameters to estimate and the total number of parameters.
%
% * 21-01-2009: Updated the documentation.
%
% * 13-03-2009: Added support for the Student-t, the Cauchy, the logistic, and the Pareto prior distributions.
%
% * 31-03-2009: Made sure that the Pareto distribution has 3 parameters.
%
% * 02-04-2009: Took into account that the logistic distribution now supports a shape parameter. Added support
%               for the Gumbel distribution.
%
% * 20-04-2009: Made sure that the fields in PriorDist have the correct length.
%
% * 05-01-2010: Updated the documentation.
%
% * 15-01-2010: Added the input variables "SmallEigenValues" and "SmallEigenVectors".
%
% * 07-02-2010: The function takes the input variable "ScreenMessages" from csminwel.
%
% * 17-03-2010: Updated the documentation.
%
% * 17-12-2010: The function now prints DSGE model solver information.
%
% * 23-12-2010: The function now prints Kalman algorithm information.
%
% * 05-01-2011: Updated the documentation.
%
% * 12-01-2011: The function now supports unix and mac paths.
%
% * 05-07-2011: Added the "OptParameters" input variable.
%
% * 13-07-2011: Changed the output for OptAlgorithm equal to gmhmaxlik.
%
% * 13-10-2011: Took into account that "KalmanAlgorithm" now supports the univariate filter and smoother.
%
% * 09-11-2011: Took into account that the Kalman filter now supports diffuse initialization.
%
% * 05-01-2012: Updated the documentation.
%
% * 22-03-2012: The function now reports the Laplace approximation based on a finite difference
%               estimator of minus the inverse Hessian at the posterior mode.
%
% * 28-03-2012: Took into account that "MargLikeLaplace" now accepts a third input variable.
%
% * 16-11-2012: The function takes the use of the Chandrasekhar recursions into account.
%
% * 03-01-2013: Updated the documentation.
%
% * 04-01-2013: Updated the documentation.
%
% * 28-01-2014: Updated the documentation.
%
% * 14-01-2015: Updated the documentation.
%
% * 07-05-2015: Fixed output for Laplace data such that the text width is 80 characters.
%
% * 27-10-2015: Fixed the screen messages header to take into account that csminwel is not
%               always used.
%
% * 22-02-2016: Updated the documentation.
%
% * 22-03-2017: Updated the documentation.
%
% * 01-06-2017: Added the input variables "LogSPIV,LogSPMode,IsSystemPrior,LogMargLikeSystemLaplace".
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

ModeTextFile = FixFilePath([DSGEModel.OutputDirectory '\PosteriorModeResults-' DSGEModel.NameOfModel '.txt']);
%
fid = fopen(ModeTextFile,'wt');
%
% the header information
%
fprintf(fid,'*********************************************************************************************************\n');
fprintf(fid,'*                                                                                                       *\n');
fprintf(fid,'*                  P O S T E R I O R   M O D E   E S T I M A T I O N   W I T H   Y A D A                *\n');
fprintf(fid,'*                                                                                                       *\n');
fprintf(fid,'*********************************************************************************************************\n\n');
%
% Model info
%
if DSGEModel.ModelSolver==1;
   SolverStr = 'Anderson & Moore (AiM)';
elseif DSGEModel.ModelSolver==2;
   SolverStr = 'Klein (solab)';
elseif DSGEModel.ModelSolver==3;
   SolverStr = 'Sims (gensys)';
end;
fprintf(fid,'Name of model:                    %s\n',DSGEModel.NameOfModel);
fprintf(fid,'DSGE model solver:                %s\n',SolverStr);
fprintf(fid,'Data construction file:           %s\n',GetFilename(DSGEModel.DataConstructionFile));
fprintf(fid,'Measurement equation file:        %s\n',GetFilename(DSGEModel.MeasurementEquationFile));
fprintf(fid,'Prior distribution data file:     %s\n',GetFilename(DSGEModel.PriorFile));
fprintf(fid,'Sheet name:                       %s\n',DSGEModel.PriorFileSheet);
if IsSystemPrior==1;
   fprintf(fid,'System prior density file:        %s\n',GetFilename(DSGEModel.SystemPriorFile));
end;
if FileExist(DSGEModel.UpdateParameterFile)==1;
   fprintf(fid,'Update parameters file:           %s\n',GetFilename(DSGEModel.UpdateParameterFile));
end;
if FileExist(DSGEModel.InitializeParameterFile)==1;
   fprintf(fid,'Initialize parameters file:       %s\n',GetFilename(DSGEModel.InitializeParameterFile));
end;
fprintf(fid,'AiM model file:                   %s\n\n',GetFilename(DSGEModel.AIMFile));
fprintf(fid,'*********************************************************************************************************\n');
fprintf(fid,'*                                                                                                       *\n');
fprintf(fid,'*                           S A M P L E   &   D A T A   I N F O R M A T I O N                           *\n');
fprintf(fid,'*                                                                                                       *\n');
fprintf(fid,'*********************************************************************************************************\n\n');
%
% Sample information
%
[NewStartYear,NewStartPeriod] = AdjustSampleStart(DSGEModel.SubBeginYear,DSGEModel.SubBeginPeriod,DSGEModel.DataFrequency,DSGEModel.KalmanFirstObservation-1);
%
fprintf(fid,'Selected sample:                  %s:%s -- %s:%s\n',DSGEModel.SubBeginYear,DSGEModel.SubBeginPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod);
fprintf(fid,'Number of observations:           %0.0f\n',DSGEModel.LastPeriod-DSGEModel.FirstPeriod+1);
fprintf(fid,'Number of observations used to\n');
fprintf(fid,'initialize the Kalman filter:     %0.0f\n',DSGEModel.KalmanFirstObservation-1);
fprintf(fid,'Effective number of observations: %0.0f\n',DSGEModel.LastPeriod-DSGEModel.FirstPeriod+1-(DSGEModel.KalmanFirstObservation-1));
fprintf(fid,'Estimation sample:                %s:%s -- %s:%s\n',NewStartYear,NewStartPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod);
%
fprintf(fid,'Number of observed variables:     %0.0f\n',min(size(DSGEModel.Y)));
fprintf(fid,'Number of exogenous variables:    %0.0f\n',min(size(DSGEModel.X)));
fprintf(fid,'Number of state variables:        %0.0f\n',size(DSGEModel.StateVariableNames,1));
fprintf(fid,'Number of state shocks:           %0.0f\n',size(DSGEModel.StateShockNames,1));
fprintf(fid,'Number of measurement errors:     %0.0f\n\n',NumMeasureErrors);
%
% observed variable names, state variable names and state shocks
%
VarNames = StrWrap(vecstr(DSGEModel.VariableNames,' '),60);
fprintf(fid,'Names of observed variables:      %s\n',VarNames(1,:));
for i=2:size(VarNames,1);
   if strcmp(StringTrim(VarNames(i,:)),'')==0;
      fprintf(fid,'                                  %s\n',VarNames(i,:));
   end;
end;
if min(size(DSGEModel.X))>0;
   XVarNames = StrWrap(vecstr(DSGEModel.XVariableNames,' '),60);
   fprintf(fid,'Names of exogenous variables:     %s\n',XVarNames(1,:));
   for i=2:size(XVarNames,1);
      if strcmp(StringTrim(XVarNames(i,:)),'')==0;
         fprintf(fid,'                                  %s\n',XVarNames(i,:));
      end;
   end;
end;
StateVarNames = StrWrap(vecstr(DSGEModel.StateVariableNames,' '),60);
fprintf(fid,'Names of state variables:         %s\n',StateVarNames(1,:));
for i=2:size(StateVarNames,1);
   if strcmp(StringTrim(StateVarNames(i,:)),'')==0;
      fprintf(fid,'                                  %s\n',StateVarNames(i,:));
   end;
end;
StateShockNames = StrWrap(vecstr(DSGEModel.StateShockNames,' '),60);
fprintf(fid,'Names of the state shocks:        %s\n',StateShockNames(1,:));
for i=2:size(StateShockNames,1);
   if strcmp(StringTrim(StateShockNames(i,:)),'')==0;
      fprintf(fid,'                                  %s\n',StateShockNames(i,:));
   end;
end;
%
fprintf(fid,'\n*********************************************************************************************************\n');
fprintf(fid,'*                                                                                                       *\n');
fprintf(fid,'*                            O P T I M I Z A T I O N   I N F O R M A T I O N                            *\n');
fprintf(fid,'*                                                                                                       *\n');
fprintf(fid,'*********************************************************************************************************\n\n');
%
% optimization information
%
if DSGEModel.KalmanAlgorithm==1;
   AlgorithmText = 'Standard filter';
elseif DSGEModel.KalmanAlgorithm==2;
   AlgorithmText = 'Square root filter';
elseif DSGEModel.KalmanAlgorithm==3;
   AlgorithmText = 'Univariate filter';
elseif DSGEModel.KalmanAlgorithm==4;
   AlgorithmText = 'Chandrasekhar recursions';
end;
if DSGEModel.UseDoublingAlgorithm==1;
   InitialAlgorithmText = 'Analytic';
elseif DSGEModel.UseDoublingAlgorithm==2;
   InitialAlgorithmText = 'Numeric (doubling algorithm)';
elseif DSGEModel.UseDoublingAlgorithm==3;
   InitialAlgorithmText = 'Constant times identity';
elseif DSGEModel.UseDoublingAlgorithm==4;
   InitialAlgorithmText = 'Diffuse';
end;
fprintf(fid,'Optimization algorithm:           %s\n',OptAlgorithm);
fprintf(fid,'Parameter target type:            %s\n',lower(OptParameters));
fprintf(fid,'Kalman algorithm:                 %s\n',AlgorithmText);
fprintf(fid,'Initialization method:            %s\n',InitialAlgorithmText);
fprintf(fid,'Time:                             %s (hrs:min:sec)\n',SecondsToHoursStr(MaxTime));
if strcmp(lower(OptAlgorithm),'gmhmaxlik')==0;
   fprintf(fid,'Tolerance level:                  %0.10f\n',ToleranceValue);
   fprintf(fid,'Maximum number of iterations:     %0.0f\n',MaxIter);
   fprintf(fid,'Number of iterations:             %0.0f\n',NumIter);
   fprintf(fid,'Convergence value:                %0.10f\n\n',FuncDiff);
else;
   fprintf(fid,'Number of parameter draws:        %0.0f\n',NumIter);
   fprintf(fid,'Objective function change:        %0.10f\n\n',FuncDiff);
end;
%
% check if we have screen messages from csminwel to provide.
%
if isempty(ScreenMessages)==0;
   fprintf(fid,'********************************************************************************\n');
   fprintf(fid,'*                                                                              *\n');
   if strcmp(lower(OptAlgorithm),'csminwel')==1;
      fprintf(fid,'*               C S M I N W E L   S C R E E N   M E S S A G E S                *\n');
   else;
      fprintf(fid,'*                        S C R E E N   M E S S A G E S                         *\n');
   end;
   fprintf(fid,'*                                                                              *\n');
   fprintf(fid,'********************************************************************************\n\n');
   for i=1:size(ScreenMessages,1);
      fprintf(fid,'%s\n',ScreenMessages(i,:));
   end;
   fprintf(fid,'\n');
end;
%
fprintf(fid,'*********************************************************************************************************\n');
fprintf(fid,'*                                                                                                       *\n');
fprintf(fid,'*                           P O S T E R I O R   D E N S I T Y   R E S U L T S                           *\n');
fprintf(fid,'*                                                                                                       *\n');
fprintf(fid,'*********************************************************************************************************\n\n');
%
% Log posterior data
%
if isnan(phiInverseHessianFinDiff)==0;
   LogMargLike = MargLikeLaplace(LogPostDensity,phiInverseHessianFinDiff,1)-LogMargLikeSystemLaplace;
else;
   LogMargLike = MargLikeLaplace(LogPostDensity,InverseHessian,1)-LogMargLikeSystemLaplace;
end;
%
prt_val = ['%' num2str(9+CurrINI.decimals,'%0.0f') '.' num2str(CurrINI.decimals,'%0.0f') 'f'];
fprintf(fid,'--------------------------------------------------------------------------------\n');
fprintf(fid,'|                     Log Posterior Density Kernel at Mode                     |\n');
fprintf(fid,'|------------------------------------------------------------------------------|\n');
fprintf(fid,['| Value of the log posterior density kernel of phi at mode:   ' prt_val '  |\n'],LogPostDensity);
fprintf(fid,['| Value of the log posterior density kernel of theta at mode: ' prt_val '  |\n'],LogPostDensity-LogJacobianValue);
fprintf(fid,['| Value of the log likelihood at theta mode:                  ' prt_val '  |\n'],LogLikeDensity);
fprintf(fid,['| Value of the log prior density of phi at phi mode:          ' prt_val '  |\n'],LogPriorDensity+LogJacobianValue);
fprintf(fid,['| Value of the log prior density of theta at theta mode:      ' prt_val '  |\n'],LogPriorDensity);
fprintf(fid,['| Value of the log Jacobian (dtheta/dphi) at mode:            ' prt_val '  |\n'],LogJacobianValue);
if IsSystemPrior==1;
   fprintf(fid,['| Value of the log system prior density of theta at mode:     ' prt_val '  |\n'],LogSPMode);
end;
fprintf(fid,'|                                                                              |\n');
fprintf(fid,'| Value of the Laplace approximation of the log marginal                       |\n');
fprintf(fid,['| likelihood based on the posterior mode of phi:              ' prt_val '  |\n'],LogMargLike);
if IsSystemPrior==1;
   fprintf(fid,'|                                                                              |\n');
   fprintf(fid,'| Value of the Laplace approximation of the log marginal                       |\n');
   fprintf(fid,['| likelihood of the system prior at prior phi mode:           ' prt_val '  |\n'],LogMargLikeSystemLaplace);
end;
fprintf(fid,'|------------------------------------------------------------------------------|\n');
fprintf(fid,'|                Log Posterior Density Kernel at Initial Value                 |\n');
fprintf(fid,'|------------------------------------------------------------------------------|\n');
fprintf(fid,['| Initial value of the log posterior density kernel of phi:   ' prt_val '  |\n'],LogPosteriorPhiIV);
fprintf(fid,['| Initial value of the log posterior density kernel of theta: ' prt_val '  |\n'],LogPosteriorThetaIV);
fprintf(fid,['| Initial value of the log likelihood at theta:               ' prt_val '  |\n'],LogPosteriorThetaIV-LogPriorDensityIV);
fprintf(fid,['| Initial value of the log prior density of phi:              ' prt_val '  |\n'],LogPriorDensityIV+LogPosteriorPhiIV-LogPosteriorThetaIV);
fprintf(fid,['| Initial value of the log prior density of theta:            ' prt_val '  |\n'],LogPriorDensityIV);
fprintf(fid,['| Initial value of the log Jacobian (dtheta/dphi):            ' prt_val '  |\n'],LogPosteriorPhiIV-LogPosteriorThetaIV);
if IsSystemPrior==1;
   fprintf(fid,['| Initial value of the log system prior density of theta:     ' prt_val '  |\n'],LogSPIV);
end;
fprintf(fid,'--------------------------------------------------------------------------------\n\n');
if IsSystemPrior==1;
   fprintf(fid,'NOTE: log posterior density kernel of phi = (log likelihood at theta + \n');
   fprintf(fid,'      log prior density at theta + log Jacobian + log system prior), while\n');
   fprintf(fid,'      the log posterior density kernel of theta = (log posterior density kernel of phi - \n');
   fprintf(fid,'      log Jacobian). Furthermore, log prior density at phi = (log prior density\n');
   fprintf(fid,'      at theta + log Jacobian). The Laplace approximation of the log marginal\n');
   fprintf(fid,'      likelihood based on the posterior mode of phi has been adjusted to account\n');
   fprintf(fid,'      for the log marginal likelihood of the system prior at prior phi mode.\n\n');
else;
   fprintf(fid,'NOTE: log posterior density kernel of phi = (log likelihood at theta + \n');
   fprintf(fid,'      log prior density at theta + log Jacobian), while the log posterior\n');
   fprintf(fid,'      density kernel of theta = (log posterior density kernel of phi - \n');
   fprintf(fid,'      log Jacobian). Furthermore, log prior density at phi = (log prior density\n');
   fprintf(fid,'      at theta + log Jacobian).\n\n');
end;
%
fprintf(fid,'NOTE: The Laplace approximation of the log marginal likelihood is calculated\n');
if isnan(phiInverseHessianFinDiff)==0;
   fprintf(fid,'      using a finite difference estimator of minus the inverse Hessian at the\n      posterior mode.\n\n');
else;
   fprintf(fid,'      using the inverse Hessian at the mode from the optimization routine.\n\n');
end;
%
% Optimization results
%
prt_val = ['%' num2str(6+CurrINI.decimals,'%0.0f') '.' num2str(CurrINI.decimals,'%0.0f') 'f'];
prt_str = ['|    %10.0f          ' prt_val '           ' prt_val '         ' prt_val '     |\n'];
fprintf(fid,'---------------------------------------------------------------------------------------\n');
if IsOdd(DSGEModel.MaximizeAlgorithmValue)==1;
   fprintf(fid,'| Iteration Number   log posterior of phi    convergence measure   max(abs(gradient)) |\n');
else;
   fprintf(fid,'| Iteration Number  log posterior of theta   convergence measure   max(abs(gradient)) |\n');
end;
fprintf(fid,'|-------------------------------------------------------------------------------------|\n');
fprintf(fid,prt_str,OptResults');
fprintf(fid,'---------------------------------------------------------------------------------------\n\n');
%
fprintf(fid,'*********************************************************************************************************\n');
fprintf(fid,'*                                                                                                       *\n');
fprintf(fid,'*                                          P A R A M E T E R S                                          *\n');
fprintf(fid,'*                                                                                                       *\n');
fprintf(fid,'*********************************************************************************************************\n\n');
%
% The parameter estimates
%
fprintf(fid,'Number of parameters to estimate: %0.0f\n',length(theta));
fprintf(fid,'Total number of parameters:       %0.0f\n\n',size(ParameterNames.all,1));
%
% we start with the estimated transformed parameters
%
if (isempty(PriorDist.truncnormal)==1)&(isempty(PriorDist.invgamma)==1)&(isempty(PriorDist.gamma)==1)&(isempty(PriorDist.beta)==1)&(isempty(PriorDist.student)==1)&(isempty(PriorDist.pareto)==1)&(isempty(PriorDist.logistic)==1);
   fprintf(fid,'===================================================================================================================\n');
   fprintf(fid,'                                              Transformed Parameters                                               \n\n');
   fprintf(fid,'      parameter           phi mode         st dev         init val       prior dist     parameter 1     parameter 2\n');
else;
   if isempty(PriorDist.beta)==1;
      fprintf(fid,'===================================================================================================================================\n');
      fprintf(fid,'                                                      Transformed Parameters                                                       \n\n');
      fprintf(fid,'      parameter           phi mode         st dev         init val       prior dist     parameter 1     parameter 2     parameter 3\n');
   else;
      fprintf(fid,'===================================================================================================================================================\n');
      fprintf(fid,'                                                      Transformed Parameters                                                                       \n\n');
      fprintf(fid,'      parameter           phi mode         st dev         init val       prior dist     parameter 1     parameter 2     parameter 3     parameter 4\n');
   end;
end;
%
% check the length of parameter names string
%
ns = size(ParameterNames.estimated,2);
if ns<20;
   add_str = SpaceStr(20-ns);
else;
   add_str = '';
end;
n_gamma = 0;
n_beta = 0;
n_normal = 0;
n_invgamma = 0;
n_truncnormal = 0;
n_uniform = 0;
n_uniform = 0;
n_student = 0;
n_cauchy = 0;
n_logistic = 0;
n_gumbel = 0;
n_pareto = 0;
prt_str = ['%s%s    ' prt_val '    ' prt_val '    ' prt_val '    %s%s    ' prt_val '    ' prt_val];
for i=1:length(phiMode);
   if thetaDist(i)==1;
      dist_str = 'gamma';
      dist_add = SpaceStr(6);
      n_gamma = n_gamma+1;
      prior_val = PriorDist.gamma(n_gamma,:);
      if length(prior_val)<3;
         prior_val = [prior_val 0];
      end;
   elseif thetaDist(i)==2;
      dist_str = 'beta';
      dist_add = SpaceStr(7);
      n_beta = n_beta+1;
      prior_val = PriorDist.beta(n_beta,:);
      if length(prior_val)<3;
         prior_val = [prior_val 0 1];
      end;
   elseif thetaDist(i)==3;
      dist_str = 'normal';
      dist_add = SpaceStr(5);
      n_normal = n_normal+1;
      prior_val = PriorDist.normal(n_normal,:);
   elseif thetaDist(i)==4;
      dist_str = 'invgamma';
      dist_add = SpaceStr(3);
      n_invgamma = n_invgamma+1;
      prior_val = PriorDist.invgamma(n_invgamma,:);
      if length(prior_val)<3;
         prior_val = [prior_val 0];
      end;
   elseif thetaDist(i)==5;
      dist_str = 'truncnormal';
      dist_add = '';
      n_truncnormal = n_truncnormal+1;
      prior_val = PriorDist.truncnormal(n_truncnormal,:);
   elseif thetaDist(i)==6;
      dist_str = 'uniform';
      dist_add = SpaceStr(4);
      n_uniform = n_uniform+1;
      prior_val = PriorDist.uniform(n_uniform,:);
   elseif thetaDist(i)==7;
      dist_str = 'student';
      dist_add = SpaceStr(4);
      n_student = n_student+1;
      prior_val = PriorDist.student(n_student,:);
   elseif thetaDist(i)==8;
      dist_str = 'cauchy';
      dist_add = SpaceStr(5);
      n_cauchy = n_cauchy+1;
      prior_val = PriorDist.cauchy(n_cauchy,:);
   elseif thetaDist(i)==9;
      dist_str = 'logistic';
      dist_add = SpaceStr(3);
      n_logistic = n_logistic+1;
      prior_val = PriorDist.logistic(n_logistic,:);
   elseif thetaDist(i)==10;
      dist_str = 'gumbel';
      dist_add = SpaceStr(5);
      n_gumbel = n_gumbel+1;
      prior_val = PriorDist.gumbel(n_gumbel,:);
   elseif thetaDist(i)==11;
      dist_str = 'pareto';
      dist_add = SpaceStr(5);
      n_pareto = n_pareto+1;
      prior_val = PriorDist.pareto(n_pareto,:);
   end;
   if (isempty(PriorDist.truncnormal)==1)&(isempty(PriorDist.invgamma)==1)&(isempty(PriorDist.gamma)==1)&(isempty(PriorDist.beta)==1)&(isempty(PriorDist.student)==1)&(isempty(PriorDist.pareto)==1)&(isempty(PriorDist.logistic)==1);
      fprintf(fid,'-------------------------------------------------------------------------------------------------------------------\n');
   else;
      if isempty(PriorDist.beta)==1;
         fprintf(fid,'-----------------------------------------------------------------------------------------------------------------------------------\n');
      else;
         fprintf(fid,'---------------------------------------------------------------------------------------------------------------------------------------------------\n');
      end;
   end;
   if (strcmp(dist_str,'truncnormal')==0)&(strcmp(dist_str,'invgamma')==0)&(strcmp(dist_str,'gamma')==0)&(strcmp(dist_str,'beta')==0)&(strcmp(dist_str,'student')==0)&(strcmp(dist_str,'pareto')==0)&(strcmp(dist_str,'logistic')==0);
      fprintf(fid,[prt_str '\n'],add_str,ParameterNames.estimated(i,:),phiMode(i),sqrt(InverseHessian(i,i)),phi(i),dist_add,dist_str,prior_val(1,1),prior_val(1,2));
   else;
      if strcmp(dist_str,'beta')==0;
         fprintf(fid,[prt_str '    ' prt_val '\n'],add_str,ParameterNames.estimated(i,:),phiMode(i),sqrt(InverseHessian(i,i)),phi(i),dist_add,dist_str,prior_val(1,1),prior_val(1,2),prior_val(1,3));
      else;
         fprintf(fid,[prt_str '    ' prt_val '    ' prt_val '\n'],add_str,ParameterNames.estimated(i,:),phiMode(i),sqrt(InverseHessian(i,i)),phi(i),dist_add,dist_str,prior_val(1,1),prior_val(1,2),prior_val(1,3),prior_val(1,4));
      end;
   end;
   if isnan(phiFittedStd)==0;
      fprintf(fid,['                                        ' prt_val '\n'],phiFittedStd(i));
   end;
   if isnan(phiPostModeStdFinDiff)==0;
      fprintf(fid,['                                        ' prt_val '\n'],phiPostModeStdFinDiff(i));
   end;
end;
if (isempty(PriorDist.truncnormal)==1)&(isempty(PriorDist.invgamma)==1)&(isempty(PriorDist.gamma)==1)&(isempty(PriorDist.beta)==1)&(isempty(PriorDist.student)==1)&(isempty(PriorDist.pareto)==1)&(isempty(PriorDist.logistic)==1);
   fprintf(fid,'===================================================================================================================\n\n');
else;
   if isempty(PriorDist.beta)==1;
      fprintf(fid,'===================================================================================================================================\n\n');
   else;
      fprintf(fid,'===================================================================================================================================================\n\n');
   end;
end;
fprintf(fid,'\nNOTE: The first standard deviation is computed from the inverse Hessian at the posterior mode.\n');
if (isnan(phiFittedStd)==0)&(isnan(phiPostModeStdFinDiff)==0);
   fprintf(fid,'      The second standard deviation is computed from a modified inverse Hessian. It is calculated\n');
   fprintf(fid,'      by fitting quadratic to evaluated log posterior values. The third standard deviation is\n');
   fprintf(fid,'      calculated from an inverse Hessian based on finite differences.\n');
elseif (isnan(phiFittedStd)==0)&(isnan(phiPostModeStdFinDiff)==1);
   fprintf(fid,'      The second standard deviation is computed from a modified inverse Hessian. It is calculated\n');
   fprintf(fid,'      by fitting quadratic to evaluated log posterior values.\n');
elseif (isnan(phiFittedStd)==1)&(isnan(phiPostModeStdFinDiff)==0);
   fprintf(fid,'      The second standard deviation is calculated from an inverse Hessian based on finite differences.\n');
end;
fprintf(fid,'\n');
%
% Calculate an approximation of the inverse Hessian for theta, the original parameters, using the
% inverse Hessian at the mode for phi, the transformed parameters, and the partial derivatives of
% theta wrt phi
%
thetaInverseHessian = ThetaPhiPartial*InverseHessian*ThetaPhiPartial;
%
if (isempty(PriorDist.truncnormal)==1)&(isempty(PriorDist.invgamma)==1)&(isempty(PriorDist.gamma)==1)&(isempty(PriorDist.beta)==1)&(isempty(PriorDist.student)==1)&(isempty(PriorDist.pareto)==1)&(isempty(PriorDist.logistic)==1);
   fprintf(fid,'===================================================================================================================\n');
   fprintf(fid,'                                                Original Parameters                                                \n\n');
   fprintf(fid,'      parameter          theta mode        st dev         init val       prior dist     parameter 1     parameter 2\n');
else;
   if isempty(PriorDist.beta)==1;
      fprintf(fid,'===================================================================================================================================\n');
      fprintf(fid,'                                                        Original Parameters                                                        \n\n');
      fprintf(fid,'      parameter          theta mode        st dev         init val       prior dist     parameter 1     parameter 2     parameter 3\n');
   else;
      fprintf(fid,'===================================================================================================================================================\n');
      fprintf(fid,'                                                        Original Parameters                                                                        \n\n');
      fprintf(fid,'      parameter          theta mode        st dev         init val       prior dist     parameter 1     parameter 2     parameter 3     parameter 4\n');
   end;
end;
%
n_gamma = 0;
n_beta = 0;
n_normal = 0;
n_invgamma = 0;
n_truncnormal = 0;
n_uniform = 0;
n_student = 0;
n_cauchy = 0;
n_logistic = 0;
n_gumbel = 0;
n_pareto = 0;
for i=1:length(phiMode);
   if thetaDist(i)==1;
      dist_str = 'gamma';
      dist_add = SpaceStr(6);
      n_gamma = n_gamma+1;
      prior_val = PriorDist.gamma(n_gamma,:);
      if length(prior_val)<3;
         prior_val = [prior_val 0];
      end;
   elseif thetaDist(i)==2;
      dist_str = 'beta';
      dist_add = SpaceStr(7);
      n_beta = n_beta+1;
      prior_val = PriorDist.beta(n_beta,:);
      if length(prior_val)<3;
         prior_val = [prior_val 0 1];
      end;
   elseif thetaDist(i)==3;
      dist_str = 'normal';
      dist_add = SpaceStr(5);
      n_normal = n_normal+1;
      prior_val = PriorDist.normal(n_normal,:);
   elseif thetaDist(i)==4;
      dist_str = 'invgamma';
      dist_add = SpaceStr(3);
      n_invgamma = n_invgamma+1;
      prior_val = PriorDist.invgamma(n_invgamma,:);
      if length(prior_val)<3;
         prior_val = [prior_val 0];
      end;
   elseif thetaDist(i)==5;
      dist_str = 'truncnormal';
      dist_add = '';
      n_truncnormal = n_truncnormal+1;
      prior_val = PriorDist.truncnormal(n_truncnormal,:);
   elseif thetaDist(i)==6;
      dist_str = 'uniform';
      dist_add = SpaceStr(4);
      n_uniform = n_uniform+1;
      prior_val = PriorDist.uniform(n_uniform,:);
   elseif thetaDist(i)==7;
      dist_str = 'student';
      dist_add = SpaceStr(4);
      n_student = n_student+1;
      prior_val = PriorDist.student(n_student,:);
   elseif thetaDist(i)==8;
      dist_str = 'cauchy';
      dist_add = SpaceStr(5);
      n_cauchy = n_cauchy+1;
      prior_val = PriorDist.cauchy(n_cauchy,:);
   elseif thetaDist(i)==9;
      dist_str = 'logistic';
      dist_add = SpaceStr(3);
      n_logistic = n_logistic+1;
      prior_val = PriorDist.logistic(n_logistic,:);
   elseif thetaDist(i)==10;
      dist_str = 'gumbel';
      dist_add = SpaceStr(5);
      n_gumbel = n_gumbel+1;
      prior_val = PriorDist.gumbel(n_gumbel,:);
   elseif thetaDist(i)==11;
      dist_str = 'pareto';
      dist_add = SpaceStr(5);
      n_pareto = n_pareto+1;
      prior_val = PriorDist.pareto(n_pareto,:);
   end;
   if (isempty(PriorDist.truncnormal)==1)&(isempty(PriorDist.invgamma)==1)&(isempty(PriorDist.gamma)==1)&(isempty(PriorDist.beta)==1)&(isempty(PriorDist.student)==1)&(isempty(PriorDist.pareto)==1)&(isempty(PriorDist.logistic)==1);
      fprintf(fid,'-------------------------------------------------------------------------------------------------------------------\n');
   else;
      if isempty(PriorDist.beta)==1;
         fprintf(fid,'-----------------------------------------------------------------------------------------------------------------------------------\n');
      else;
         fprintf(fid,'---------------------------------------------------------------------------------------------------------------------------------------------------\n');
      end;
   end;
   if (strcmp(dist_str,'truncnormal')==0)&(strcmp(dist_str,'invgamma')==0)&(strcmp(dist_str,'gamma')==0)&(strcmp(dist_str,'beta')==0)&(strcmp(dist_str,'student')==0)&(strcmp(dist_str,'pareto')==0)&(strcmp(dist_str,'logistic')==0);
      fprintf(fid,[prt_str '\n'],add_str,ParameterNames.estimated(i,:),thetaMode(i),sqrt(thetaInverseHessian(i,i)),theta(i),dist_add,dist_str,prior_val(1,1),prior_val(1,2));
   else;
      if strcmp(dist_str,'beta')==0;
         fprintf(fid,[prt_str '    ' prt_val '\n'],add_str,ParameterNames.estimated(i,:),thetaMode(i),sqrt(thetaInverseHessian(i,i)),theta(i),dist_add,dist_str,prior_val(1,1),prior_val(1,2),prior_val(1,3));
      else;
         fprintf(fid,[prt_str '    ' prt_val '    ' prt_val '\n'],add_str,ParameterNames.estimated(i,:),thetaMode(i),sqrt(thetaInverseHessian(i,i)),theta(i),dist_add,dist_str,prior_val(1,1),prior_val(1,2),prior_val(1,3),prior_val(1,4));
      end;
   end;
   if isnan(thetaFittedStd)==0;
      fprintf(fid,['                                        ' prt_val '\n'],thetaFittedStd(i));
   end;
   if isnan(thetaPostModeStdFinDiff)==0;
      fprintf(fid,['                                        ' prt_val '\n'],thetaPostModeStdFinDiff(i));
   end;
end;
if (isempty(PriorDist.truncnormal)==1)&(isempty(PriorDist.invgamma)==1)&(isempty(PriorDist.gamma)==1)&(isempty(PriorDist.beta)==1)&(isempty(PriorDist.student)==1)&(isempty(PriorDist.pareto)==1)&(isempty(PriorDist.logistic)==1);
   fprintf(fid,'===================================================================================================================\n\n');
else;
   if isempty(PriorDist.beta)==1;
      fprintf(fid,'===================================================================================================================================\n\n');
   else;
      fprintf(fid,'===================================================================================================================================================\n\n');
   end;
end;
fprintf(fid,'NOTE: The first standard deviation is computed from the inverse Hessian at the posterior mode.\n');
fprintf(fid,'      It has been computed from the inverse Hessian of phi at the mode using partial derivatives.\n');
if (isnan(phiFittedStd)==0)&(isnan(phiPostModeStdFinDiff)==0)&(DSGEModel.CheckTransformedOptimum==0);
   fprintf(fid,'      The second standard deviation is computed from a modified inverse Hessian. It is calculated\n');
   fprintf(fid,'      by fitting quadratic to evaluated log posterior values. The third standard deviation is\n');
   fprintf(fid,'      calculated from an inverse Hessian based on finite differences.\n');
elseif (isnan(phiFittedStd)==0)&(isnan(phiPostModeStdFinDiff)==1)&(DSGEModel.CheckTransformedOptimum==0);
   fprintf(fid,'      The second standard deviation is computed from a modified inverse Hessian. It is calculated\n');
   fprintf(fid,'      by fitting quadratic to evaluated log posterior values.\n');
elseif (isnan(phiFittedStd)==1)&(isnan(phiPostModeStdFinDiff)==0);
   fprintf(fid,'      The second standard deviation is calculated from an inverse Hessian based on finite differences.\n');
end;
fprintf(fid,'\n');
%
% Print the calibrated parameters and their values
%
if isempty(thetaCalibrated)==0;
   ns = size(ParameterNames.calibrated,2);
   if ns<20;
      cal_add_str = SpaceStr(20-ns);
   else;
      cal_add_str = '';
   end;
   %
   fprintf(fid,'==============================================================\n');
   fprintf(fid,'        Calibrated Parameters\n');
   fprintf(fid,'     parameter              value\n');
   prt_str = ['%s%s    ' prt_val '\n'];
   for i=1:length(thetaCalibrated);
      fprintf(fid,'--------------------------------------------------------------\n');
      fprintf(fid,prt_str,cal_add_str,ParameterNames.calibrated(i,:),thetaCalibrated(i));
   end;
   fprintf(fid,'==============================================================\n\n');
end;
%
% print any additional parameters values
%
if isempty(thetaAdditionalInitial)==0;
   ns = size(ParameterNames.additional,2);
   if ns<20;
      upd_add_str = SpaceStr(20-ns);
   else;
      upd_add_str = '';
   end;
   %
   fprintf(fid,'==============================================================\n');
   fprintf(fid,'               Additional Parameters\n');
   fprintf(fid,'     parameter              mode         init value\n');
   prt_str = ['%s%s    ' prt_val '    ' prt_val '\n'];
   for i=1:length(thetaAdditionalInitial);
      fprintf(fid,'--------------------------------------------------------------\n');
      fprintf(fid,prt_str,upd_add_str,ParameterNames.additional(i,:),thetaAdditionalMode(i),thetaAdditionalInitial(i));
   end;
   fprintf(fid,'==============================================================\n\n');
end;
%
% Print the maximum eigenvalues at the mode and at the initial values
%
fprintf(fid,'==============================================================\n');
fprintf(fid,' Maximum absolute eigenvalue of the state transition matrix F \n');
fprintf(fid,'--------------------------------------------------------------\n');
fprintf(fid,[' At initial parameter values:   ' prt_val '\n'],MaxEigenvalueIV);
fprintf(fid,[' At posterior mode values:      ' prt_val '\n'],MaxEigenvalueMode);
fprintf(fid,'==============================================================\n\n');
%
% Now we turn to ExtremeCorrParameters, a cell array containing the parameters with correlations above or equal to
% 0.7 at the mode 
%
if isempty(ExtremeCorrParameters)==0;
   prt_str = ['      %s%s    %s%s    ' prt_val '\n'];
   fprintf(fid,'=======================================================================\n');
   fprintf(fid,' Parameters with an absolute correlation at the mode of 0.7 or greater\n\n');
   fprintf(fid,'              parameter 1             parameter 2      correlation\n');
   fprintf(fid,'-----------------------------------------------------------------------\n');
   for i=1:size(ExtremeCorrParameters,1);
      fprintf(fid,prt_str,add_str,ExtremeCorrParameters{i,1},add_str,ExtremeCorrParameters{i,2},ExtremeCorrParameters{i,3});
   end;
   fprintf(fid,'=======================================================================\n\n');
end;
%
% check if there are small eigenvalues to print
%
if isempty(SmallEigenValues)==0;
   [p,s] = size(SmallEigenVectors);
   ns = size(ParameterNames.estimated,2);
   if ns<20;
      AddStr = SpaceStr(20-ns);
   else;
      AddStr = '';
   end;
   %
   fprintf(fid,'********************************************************************************\n');
   fprintf(fid,'*                                                                              *\n');
   fprintf(fid,'*       E I G E N V E C T O R S   A S S O C I A T E D   W I T H   T H E        *\n');
   fprintf(fid,'*            S M A L L E S T   E I G E N V A L U E S   O F   T H E             *\n');
   fprintf(fid,'*     C O R R E L A T I O N   M A T R I X   F O R   T H E   I N V E R S E      *\n');
   fprintf(fid,'*          H E S S I A N   A T   T H E   P O S T E R I O R   M O D E           *\n');
   fprintf(fid,'*                                                                              *\n');
   fprintf(fid,'********************************************************************************\n\n');
   %
   PrtStr = ['   %s%s   %' num2str(4+CurrINI.decimals,'%0.0f') '.' num2str(CurrINI.decimals,'%0.0f') 'f'];
   for i=1:s;
      fprintf(fid,'======================================================\n');
      fprintf(fid,'   Parameter             eigenvector       eigenvalue \n');
      fprintf(fid,'------------------------------------------------------\n');
      for j=1:p;
         if j>1;
            fprintf(fid,[PrtStr ' \n'],ParameterNames.estimated(j,:),AddStr,SmallEigenVectors(j,i));
         else;
            fprintf(fid,[PrtStr '   %14.10f \n'],ParameterNames.estimated(1,:),AddStr,SmallEigenVectors(j,i),SmallEigenValues(i));
         end;
      end;
      fprintf(fid,'======================================================\n\n');
   end;
   fprintf(fid,'NOTE: An eigenvalues is considered small if it is below 0.01.\n\n');
end;
%
fprintf(fid,'*********************************************************************************************************\n');
fprintf(fid,'*                                                                                                       *\n');
fprintf(fid,'*                                     F O R E C A S T   E R R O R S                                     *\n');
fprintf(fid,'*                                                                                                       *\n');
fprintf(fid,'*********************************************************************************************************\n\n');
%
% print results about the mean squared errors
%
prt_str = ['%s%s   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '\n'];
if size(DSGEModel.VariableNames,2)<15;
   add_str = SpaceStr(15-size(DSGEModel.VariableNames,2));
else;
   add_str = '';
end;
fprintf(fid,'=============================================================================\n');
fprintf(fid,'                      Mean Forecast Error       Mean Squared Forecast Error  \n');
fprintf(fid,'    Variable          mode          init val        mode          init val   \n');
fprintf(fid,'-----------------------------------------------------------------------------\n');
for i=1:size(DSGEModel.VariableNames,1);
   fprintf(fid,prt_str,add_str,DSGEModel.VariableNames(i,:),MFEYMode(i,1),MFEYIV(i,1),MSEYMode(i,i),MSEYIV(i,i));
end;
fprintf(fid,'=============================================================================\n\n');
%
% Some information about the filename and its location
%
fprintf(fid,'Directory for file: %s\n',GetPath(ModeTextFile));
fprintf(fid,'Name of file:       %s\n',GetFilename(ModeTextFile));
fprintf(fid,'Output created on:  %s\n\n',datestr(now,0));
fclose(fid);

%
% end of PrintPosteriorModeResults.m
%
