function z = YADARndGammaUnitScale(a,NumDraws)
% YADARndGammaUnitScale: Computes random draws from the gamma distribution with shape
%                        parameter a and unit scale parameter.
%
% USAGE:
%
%       z = YADARndGammaUnitScale(a,NumDraws)
%
% REQUIRED INPUT:  a (scalar) with the a (shape) parameter of the gamma distribution.
%
%                  NumDraws (integer) with the number of draws of z.
%
% REQUIRED OUTPUT: z (vector) of draws with dimension NumDraws x 1.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   DG-R/MPR
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2017 European Central Bank.
%
% NOTE: This function is based on rgamma.m in the Stixbox toolbox. The rgamma function is
%       licensed under the GNU Public Licence, Copyright (c) Anders Holtsberg 10-05-2000.
%
%                       First version: March 12, 2009.
%                        This version: March 22, 2017.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 13-03-2009: Updated the documentation.
%
% * 05-01-2010: Updated the documentation.
%
% * 05-01-2011: Updated the documentation.
%
% * 05-01-2012: Updated the documentation.
%
% * 03-01-2013: Updated the documentation.
%
% * 28-01-2014: Updated the documentation.
%
% * 14-01-2015: Updated the documentation.
%
% * 22-02-2016: Updated the documentation.
%
% * 22-03-2017: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

y0 = log(a)-1/sqrt(a);
c = a - exp(y0);
m = ceil(NumDraws*(1.7+0.6*(a<2)));
%
y = log(rand(m,1)).*sign(rand(m,1)-0.5)/c+log(a);
f = (a*y)-exp(y)-(a*y0-exp(y0));
g = c*(abs((y0-log(a))) - abs(y-log(a)));
reject = (log(rand(m,1))+g)>f;
y(reject) = [];
if length(y)>=NumDraws
   z = exp(y(1:NumDraws));
else
   z = [exp(y);YADARndGammaUnitScale(a,NumDraws-length(y))];
end

%
% end of YADARndGammaUnitScale.m
%
